<template>
  <div>
    <el-dialog
      width="50%"
      :title="`${title}区域`"
      :visible="visible"
      :before-close="handleClose"
      v-if="visible"
    >
      <el-form
        ref="formInfo"
        :rules="rules"
        :model="params"
        label-width="120px"
      >
        <el-row>
          <el-col :span="22">
            <el-form-item prop="name" label="区域名称">
              <el-input
                maxlength="64"
                placeholder="请输入单位名称"
                v-model="params.name"
              ></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="22">
            <el-form-item prop="code" label="区域编码">
              <el-input
                maxlength="32"
                placeholder="请输入区域编码"
                v-model="params.code"
              ></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="22">
            <el-form-item prop="code" label="区域简称">
              <el-input
                maxlength="64"
                placeholder="请输入区域简称"
                v-model="params.shortName"
              ></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <!-- <el-col :span="22">
  <el-form-item prop="type" label="区域类型" class="company-type">
    <el-radio-group v-model="params.type" @change="changeType">
      <el-radio v-for="item in areaTypeFilter" :key="item.value" :label="item.value">
        {{ item.name }}
      </el-radio>
    </el-radio-group>
  </el-form-item>
</el-col> -->
          <el-col :span="22">
            <el-form-item label="备注" prop="memo">
              <el-input
                maxlength="500"
                type="textarea"
                :autosize="{minRows: 3, maxRows: 4}"
                placeholder="请输入备注内容"
                v-model="params.memo"
              >
              </el-input>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <span slot="footer" class="dialog-footer">
                <el-button type="primary" @click="handleSave">保 存</el-button>
                <el-button @click="handleClose">取 消</el-button>
            </span>
    </el-dialog>
  </div>
</template>
<script>
import resourceManage from '@/api/device/resourceManage.js'
import utils from '@/hotent-ui-util.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import {ExtendParamsMixin} from '@/mixins/extendParams.js'

export default {
  name: 'regionManageModal',
  mixins: [ExtendParamsMixin],
  data() {
    return {
      visible: false,
      title: '新增',
      activeCollapse: '1',
      params: {
        name: '',
        code: '',
        type: 5,
        memo: '',
        shortName: ''
      },
      areaType: [], //区域类型
      areaTypeFilter: [], //区域类型过滤 根据父级节点类型过滤
      rules: {
        name: [
          {
            required: true,
            message: '请输入区域名称',
            trigger: 'blur'
          }
        ],
        code: [
          {
            required: true,
            message: '请输入区域编码',
            trigger: 'blur'
          }
        ],
        shortName: [
          {
            required: true,
            message: '请输入区域简称',
            trigger: 'blur'
          }
        ]
        // type: [{
        // 	required: true,
        // 	message: '请输入区域类型',
        // 	trigger: 'blur',
        // }, ],
      },
      parentRow: {}
    }
  },
  created() {
  },
  methods: {
    changeType() {
      this.$forceUpdate()
    },
    add(treeNode) {
      this.areaType = dictUtils.getDictItemsFromCache('qylx')
      this.parentRow = utils.deepClone(treeNode)
      this.visible = true
    },
    edit(row, treeNode) {
      this.areaType = dictUtils.getDictItemsFromCache('qylx')
      this.parentRow = utils.deepClone(treeNode)
      this.params = utils.deepClone(row)
      this.visible = true
      this.title = '修改'
    },
    // setAreaType(parentRow) {
    //     this.parentRow = utils.deepClone(parentRow)
    //     if (this.parentRow.type == '1') {
    //         this.areaTypeFilter = this.areaType.slice(0)
    //     } else if (this.parentRow.type == '2') {
    //         this.areaTypeFilter = this.areaType.slice(1)
    //     } else if (this.parentRow.type == '3') {
    //         this.areaTypeFilter = this.areaType.slice(2)
    //     } else if (this.parentRow.type == '4') {
    //         this.areaTypeFilter = this.areaType.slice(3)
    //     } else if (this.parentRow.type == '5') {
    //         this.areaTypeFilter = this.areaType.slice(4)
    //     }
    //     this.params.type = this.areaTypeFilter[0].value
    // },
    handleClose() {
      this.params = {
        name: '',
        code: '',
        type: 5,
        memo: '',
        shortName: ''
      }
      this.title = '新增'
      this.visible = false
      this.activeCollapse = '1'
    },
    handleSave() {
      this.$refs.formInfo.validate((valid) => {
        if (valid) {
          let tempData = utils.deepClone(this.params)
          if (!tempData.parentId) {
            tempData.parentId = this.parentRow.id
          }
          let method
          if (this.title === '新增') {
            method = resourceManage.addArea
          } else if (this.title === '修改') {
            method = resourceManage.editArea
          }
          method(tempData, (response) => {
            if (response.state) {
              this.$notify({
                type: 'success',
                message: this.title + '成功',
                duration: 2000
              })
              this.handleClose()
              this.$emit('reload')
            } else {
              this.$message.warning(response.message)
            }
          })
        } else {
          this.$notify({
            type: 'warning',
            message: '请完善表单信息！',
            duration: 2000
          })
        }
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.company-type ::v-deep .el-checkbox-group {
  height: initial !important;
}
</style>
